@@ -33,6 +33,11 @@ namespace giac {
   // true if ch is alphanumeric
   bool isalphan(char ch);
 
+  bool is_python_builtin(const char * s);
+  bool is_python_keyword(const char * s);
+  extern const char * python_keywords[];
+  extern const char * const python_builtins[];
+
   // search if cmd_name has static describing help
   // NB: cmd_name may be localized but related is not localized
   bool has_static_help(const char * & cmd_name,int lang,const char * & howto,const char * & syntax,const char * & examples,const char * & related);
@@ -84,7 +89,7 @@ namespace giac {
   aide helpon(const std::string & demande,const std::vector<aide> & v,int language,int count,bool with_op=true);
   std::string writehelp(const aide & cur_aide,int language);
 
-#if !defined(NSPIRE_NEWLIB) && !defined(RTOS_THREADX) && !defined(EMCC) && !defined(NSPIRE) && !defined(FXCG) && !defined KHICAS
+#if !defined(NSPIRE_NEWLIB) && !defined(RTOS_THREADX) && !defined(EMCC) && !defined(EMCC2) && !defined(NSPIRE) && !defined(FXCG) && !defined KHICAS
   extern std::multimap<std::string,std::string> html_mtt,html_mall;
   extern std::vector<std::string> html_vtt,html_vall;
 
